<?php

namespace Bixo\Announcement\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Announcement\Actions\AnnouncementAction;
use Bixo\Announcement\Http\Requests\AnnouncementActionRequest;
use Bixo\Announcement\Http\Resources\AnnouncementResource;
use Bixo\Announcement\Models\Announcement;

/**
 * Admin web controller class.
 */
class AnnouncementActionController extends BaseController
{

    /**
     * Action controller function for announcement.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AnnouncementActionRequest $request, Announcement $announcement, $action)
    {
        try {
            $request = $request->all();
            $announcement = AnnouncementAction::run($action, $announcement, $request);

            $data = new AnnouncementResource($announcement);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('announcement::announcement.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('announcement/announcement/' . $announcement->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/announcement/' . $announcement->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
