<?php

namespace Bixo\Announcement\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Announcement\Http\Resources\AnnouncementResource;
use Bixo\Announcement\Http\Resources\AnnouncementsCollection;
use Bixo\Announcement\Scopes\AnnouncementPublicScope;
use Bixo\Announcement\Models\Announcement;

class AnnouncementPublicController extends BaseController
{

    /**
     * Show announcement's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Announcement::pushScope(new RequestScope())
            ->pushScope(new AnnouncementPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $announcements = new AnnouncementsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('announcement::announcement.names'))
            ->view('announcement::public.announcement.index')
            ->data(compact('announcements', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show announcement.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Announcement::findBySlug($slug);
        $data = new AnnouncementResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('announcement::announcement.name'))
            ->view('announcement::public.announcement.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
