<?php

namespace Bixo\Announcement\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Announcement\Events\AnnouncementAction as AnnouncementActionEvent;
use Bixo\Announcement\Notifications\AnnouncementAction as AnnouncementActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AnnouncementAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AnnouncementActionEvent.
     *
     * @param   AnnouncementActionEvent  $event
     * @return mixed
     */
    public function handle(AnnouncementActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $announcement.
     *
     * @param   AnnouncementActionEvent  $event
     * @return void
     */
    public function create(AnnouncementActionEvent $event)
    {
        $client = $event->announcement->client;
        Notification::send($client, new AnnouncementActionNotification($event));
    }

    /**
     * Handle the AnnouncementActionEvent as a listener.
     *
     * @param   AnnouncementActionEvent  $event
     * @return mixed
     */
    public function asListener(AnnouncementActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AnnouncementActionEvent  $event
     * @return bool
     */
    private function isAllowed(AnnouncementActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
