<?php

namespace Bixo\Announcement\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Announcement\Events\AnnouncementWorkflow as AnnouncementWorkflowEvent;
use Bixo\Announcement\Notifications\AnnouncementWorkflow as AnnouncementWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AnnouncementWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AnnouncementWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $announcement is submitted.
     *
     * @param AnnouncementWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AnnouncementWorkflowEvent $event)
    {
        $client = $event->announcement->client;
        Notification::send($client, new AnnouncementWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $announcement is published.
     *
     * @param AnnouncementWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AnnouncementWorkflowEvent $event)
    {
        $client = $event->announcement->client;
        Notification::send($client, new AnnouncementWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $announcement is approved.
     *
     * @param AnnouncementWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AnnouncementWorkflowEvent $event)
    {
        $client = $event->announcement->client;
        Notification::send($client, new AnnouncementWorkflowNotification($event));
    }

    /**
     * Handles the $announcement workflow event as a listener.
     *
     * @param AnnouncementWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AnnouncementWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
