<?php
namespace Bixo\Announcement\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Announcement\Events\AnnouncementAction as AnnouncementActionEvent;
use Bixo\Announcement\Models\Announcement;

class AnnouncementAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $announcement;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AnnouncementActionEvent $announcement
     */
    public function __construct(AnnouncementActionEvent $announcement)
    {
        $this->action = $event->action;
        $this->announcement = $announcement;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Announcement Approved - ' . config('app.name'))
            ->view('announcement::announcement.email.action', ['data' => $this->announcement]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
