<?php

namespace Bixo\Announcement\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Announcement\Models\Announcement;

class AnnouncementPolicy
{

    use AnnouncementAction;
    use AnnouncementReport;
    use AnnouncementWorkflow;

    /**
     * Determine if the given user can view the announcement.
     *
     * @param Authenticatable $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function view(Authenticatable $user, Announcement $announcement)
    {
        if ($authUser->canDo('announcement.announcement.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $announcement->is_owner;
    }

    /**
     * Determine if the given user can create a announcement.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('announcement.announcement.create');
    }

    /**
     * Determine if the given user can update the given announcement.
     *
     * @param Authenticatable $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function update(Authenticatable $user, Announcement $announcement)
    {
        if ($user->canDo('announcement.announcement.edit') && $user->isAdmin()) {
            return true;
        }

        return $announcement->is_owner;
    }

    /**
     * Determine if the given user can delete the given announcement.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Announcement $announcement)
    {
        return $announcement->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
